summaryrefslogtreecommitdiff
path: root/src/api/cpp/cvc5_checks.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/api/cpp/cvc5_checks.h')
-rw-r--r--src/api/cpp/cvc5_checks.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/src/api/cpp/cvc5_checks.h b/src/api/cpp/cvc5_checks.h
index 9cfa0d252..d332652fd 100644
--- a/src/api/cpp/cvc5_checks.h
+++ b/src/api/cpp/cvc5_checks.h
@@ -29,19 +29,19 @@ namespace api {
/**
* The base check macro.
* Throws a CVC4ApiException if 'cond' is false.
*/
#define CVC5_API_CHECK(cond) \
CVC5_PREDICT_TRUE(cond) \
- ? (void)0 : OstreamVoider() & CVC4ApiExceptionStream().ostream()
+ ? (void)0 : OstreamVoider() & CVC5ApiExceptionStream().ostream()
/**
* The base check macro for throwing recoverable exceptions.
* Throws a CVC4RecoverableApiException if 'cond' is false.
*/
#define CVC5_API_RECOVERABLE_CHECK(cond) \
CVC5_PREDICT_TRUE(cond) \
- ? (void)0 : OstreamVoider() & CVC4ApiRecoverableExceptionStream().ostream()
+ ? (void)0 : OstreamVoider() & CVC5ApiRecoverableExceptionStream().ostream()
/* -------------------------------------------------------------------------- */
/* Not null checks. */
@@ -87,7 +87,7 @@ namespace api {
CVC5_PREDICT_TRUE(cond) \
? (void)0 \
: OstreamVoider() \
- & CVC4ApiExceptionStream().ostream() \
+ & CVC5ApiExceptionStream().ostream() \
<< "Invalid kind '" << kindToString(kind) << "', expected "
/* -------------------------------------------------------------------------- */
@@ -103,7 +103,7 @@ namespace api {
CVC5_PREDICT_TRUE(cond) \
? (void)0 \
: OstreamVoider() \
- & CVC4ApiExceptionStream().ostream() \
+ & CVC5ApiExceptionStream().ostream() \
<< "Invalid argument '" << arg << "' for '" << #arg \
<< "', expected "
@@ -116,7 +116,7 @@ namespace api {
CVC5_PREDICT_TRUE(cond) \
? (void)0 \
: OstreamVoider() \
- & CVC4ApiRecoverableExceptionStream().ostream() \
+ & CVC5ApiRecoverableExceptionStream().ostream() \
<< "Invalid argument '" << arg << "' for '" << #arg \
<< "', expected "
@@ -131,7 +131,7 @@ namespace api {
CVC5_PREDICT_TRUE(cond) \
? (void)0 \
: OstreamVoider() \
- & CVC4ApiExceptionStream().ostream() \
+ & CVC5ApiExceptionStream().ostream() \
<< "Invalid size of argument '" << #arg << "', expected "
/**
@@ -147,7 +147,7 @@ namespace api {
CVC5_PREDICT_TRUE(cond) \
? (void)0 \
: OstreamVoider() \
- & CVC4ApiExceptionStream().ostream() \
+ & CVC5ApiExceptionStream().ostream() \
<< "Invalid " << (what) << " in '" << #args << "' at index " \
<< (idx) << ", expected "
generated by cgit on debian on lair
@@ -29,19 +29,19 @@ namespace api {
/**
* The base check macro.
- * Throws a CVC4ApiException if 'cond' is false.
+ * Throws a CVC5ApiException if 'cond' is false.
*/
#define CVC5_API_CHECK(cond) \
@@ -29,19 +29,19 @@ namespace api {
/**
* The base check macro for throwing recoverable exceptions.
- * Throws a CVC4RecoverableApiException if 'cond' is false.
+ * Throws a CVC5ApiRecoverableException if 'cond' is false.
*/
#define CVC5_API_RECOVERABLE_CHECK(cond) \
contact matthew@masot.net with questions or feedback